==> opennms-webapp-1.11.94-sources.jar: org/opennms/web/command/ManageReportScheduleCommand.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2009-2012 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2012 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.web.command;

/**
 * <p>ManageReportScheduleCommand class.</p>
 *
 * @author ranger
 * @version $Id: $
 * @since 1.8.1
 */
public class ManageReportScheduleCommand {
    
    private String[] m_triggerNames;

    /**
     * <p>setTriggerNames</p>
     *
     * @param triggerNames an array of {@link java.lang.String} objects.
     */
    public void setTriggerNames(String[] triggerNames) {
        m_triggerNames = triggerNames;
    }

    /**
     * <p>getTriggerNames</p>
     *
     * @return an array of {@link java.lang.String} objects.
     */
    public String[] getTriggerNames() {
        return m_triggerNames;
    }

}

==> opennms-webapp-15.0.1-sources.jar: org/opennms/web/command/ManageReportScheduleCommand.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2006-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.web.command;

import java.util.Arrays;

/**
 * <p>ManageReportScheduleCommand class.</p>
 *
 * @author ranger
 * @version $Id: $
 * @since 1.8.1
 */
public class ManageReportScheduleCommand {
    
    private String[] m_triggerNames;

    /**
     * <p>setTriggerNames</p>
     *
     * @param triggerNames an array of {@link java.lang.String} objects.
     */
    public void setTriggerNames(String[] triggerNames) {
        m_triggerNames = Arrays.copyOf(triggerNames, triggerNames.length);
    }

    /**
     * <p>getTriggerNames</p>
     *
     * @return an array of {@link java.lang.String} objects.
     */
    public String[] getTriggerNames() {
        return m_triggerNames;
    }

}
